"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getForeignAssetAddress = exports.getAssetFullyQualifiedType = void 0;
var utils_1 = require("ethers/lib/utils");
var js_sha3_1 = require("js-sha3");
var utils_2 = require("../utils");
var getAssetFullyQualifiedType = function (tokenBridgeAddress, // 32 bytes
originChain, originAddress) {
    // native asset
    if (originChain === utils_2.CHAIN_ID_APTOS) {
        // originAddress should be of form address::module::type
        if (/(0x)?[0-9a-fA-F]+::\w+::\w+/g.test(originAddress)) {
            console.error("Need fully qualified address for native asset");
            return null;
        }
        return utils_2.ensureHexPrefix(originAddress);
    }
    // non-native asset, derive unique address
    var wrappedAssetAddress = exports.getForeignAssetAddress(tokenBridgeAddress, originChain, originAddress);
    return wrappedAssetAddress ? utils_2.ensureHexPrefix(wrappedAssetAddress) + "::coin::T" : null;
};
exports.getAssetFullyQualifiedType = getAssetFullyQualifiedType;
var getForeignAssetAddress = function (tokenBridgeAddress, // 32 bytes
originChain, originAddress) {
    if (originChain === utils_2.CHAIN_ID_APTOS) {
        return null;
    }
    var chain = Buffer.alloc(2);
    chain.writeUInt16BE(originChain);
    return js_sha3_1.sha3_256(Buffer.concat([
        utils_2.hex(utils_1.hexZeroPad(tokenBridgeAddress, 32)),
        chain,
        Buffer.from("::", "ascii"),
        utils_2.hex(utils_1.hexZeroPad(originAddress, 32)),
    ]));
};
exports.getForeignAssetAddress = getForeignAssetAddress;
