import { hexZeroPad } from "ethers/lib/utils";
import { sha3_256 } from "js-sha3";
import { CHAIN_ID_APTOS, ensureHexPrefix, hex } from "../utils";
export var getAssetFullyQualifiedType = function (tokenBridgeAddress, // 32 bytes
originChain, originAddress) {
    // native asset
    if (originChain === CHAIN_ID_APTOS) {
        // originAddress should be of form address::module::type
        if (/(0x)?[0-9a-fA-F]+::\w+::\w+/g.test(originAddress)) {
            console.error("Need fully qualified address for native asset");
            return null;
        }
        return ensureHexPrefix(originAddress);
    }
    // non-native asset, derive unique address
    var wrappedAssetAddress = getForeignAssetAddress(tokenBridgeAddress, originChain, originAddress);
    return wrappedAssetAddress ? ensureHexPrefix(wrappedAssetAddress) + "::coin::T" : null;
};
export var getForeignAssetAddress = function (tokenBridgeAddress, // 32 bytes
originChain, originAddress) {
    if (originChain === CHAIN_ID_APTOS) {
        return null;
    }
    var chain = Buffer.alloc(2);
    chain.writeUInt16BE(originChain);
    return sha3_256(Buffer.concat([
        hex(hexZeroPad(tokenBridgeAddress, 32)),
        chain,
        Buffer.from("::", "ascii"),
        hex(hexZeroPad(originAddress, 32)),
    ]));
};
